mdt.gui.model_fit.tabs package
==============================

Submodules
----------

mdt.gui.model_fit.tabs.fit_model_tab module
-------------------------------------------

.. automodule:: mdt.gui.model_fit.tabs.fit_model_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.tabs.generate_brain_mask_tab module
-----------------------------------------------------

.. automodule:: mdt.gui.model_fit.tabs.generate_brain_mask_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.tabs.generate_protocol_tab module
---------------------------------------------------

.. automodule:: mdt.gui.model_fit.tabs.generate_protocol_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.tabs.generate_roi_mask_tab module
---------------------------------------------------

.. automodule:: mdt.gui.model_fit.tabs.generate_roi_mask_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.tabs.view_results_tab module
----------------------------------------------

.. automodule:: mdt.gui.model_fit.tabs.view_results_tab
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mdt.gui.model_fit.tabs
    :members:
    :undoc-members:
    :show-inheritance:
